/* gtkframedcombo.h
 *
 * This file is part of the MandrakeSoft Gtk Widgets Package
 * Copyright (C) 2000 DindinX <odin@mandrakesoft.com>
 * Copyright (C) 2000 MandrakeSoft
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_FRAMED_COMBO_H__
#define __GTK_FRAMED_COMBO_H__

#include <gtk/gtkframe.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_FRAMED_COMBO            (gtk_framed_combo_get_type())
#define GTK_FRAMED_COMBO(obj)            (GTK_CHECK_CAST((obj), GTK_TYPE_FRAMED_COMBO, GtkFramedCombo))
#define GTK_FRAMED_COMBO_CLASS(klass)    (GTK_CHECK_CLASS_CAST((klass), GTK_TYPE_FRAMED_COMBO, GtkFramedComboClass))
#define GTK_IS_FRAMED_COMBO(obj)         (GTK_CHECK_TYPE((obj), GTK_TYPE_FRAMED_COMBO))
#define GTK_IS_FRAMED_COMBO_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GTK_TYPE_FRAMED_COMBO))

typedef struct _GtkFramedCombo       GtkFramedCombo;
typedef struct _GtkFramedComboClass  GtkFramedComboClass;


struct _GtkFramedCombo
{
  GtkFrame frame;

  GtkWidget *Label, *Combo;
  GtkWidget *entry, *list;
};

struct _GtkFramedComboClass
{
  GtkFrameClass parent_class;
};

/* FramedCombo */

GtkType    gtk_framed_combo_get_type(void);
GtkWidget *gtk_framed_combo_new(gchar *Label);

/* the text in the entry must be or not be in the list */
void gtk_framed_combo_set_value_in_list(GtkFramedCombo *FramedCombo,
                                        gint val,
                                        gint ok_if_empty);
/* set/unset arrows working for changing the value (can be annoying */
void gtk_framed_combo_set_use_arrows(GtkFramedCombo *FramedCombo,
                                     gint val);
/* up/down arrows change value if current value not in list */
void gtk_framed_combo_set_use_arrows_always(GtkFramedCombo *FramedCombo,
                                            gint val);
/* perform case-sensitive compares */
void gtk_framed_combo_set_case_sensitive(GtkFramedCombo *FramedCombo,
                                         gint val);
/* call this function on an item if it isn't a label or you
 *    want it to have a different value to be displayed in the entry */
void gtk_framed_combo_set_item_string(GtkFramedCombo *FramedCombo,
                                      GtkItem *item,
                                      const gchar *item_value);
/* simple interface */
void gtk_framed_combo_set_popdown_strings(GtkFramedCombo *FramedCombo,
                                          GList *strings);

void gtk_framed_combo_disable_activate(GtkFramedCombo *FramedCombo);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GTK_FRAMED_COMBO_H__ */
