/* gtkmdkdialog.h
 *
 * This file is part of the MandrakeSoft Gtk Widgets Package
 * Copyright (C) 2000 DindinX <odin@@mandrakesoft.com>
 * Copyright (C) 2000 MandrakeSoft
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_MDK_DIALOG_H__
#define __GTK_MDK_DIALOG_H__

#include <gtk/gtkdialog.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_MDK_DIALOG            (gtk_mdk_dialog_get_type())
#define GTK_MDK_DIALOG(obj)            (GTK_CHECK_CAST((obj), GTK_TYPE_MDK_DIALOG, GtkMdkDialog))
#define GTK_MDK_DIALOG_CLASS(klass)    (GTK_CHECK_CLASS_CAST((klass), GTK_TYPE_MDK_DIALOG, GtkMdkDialogClass))
#define GTK_IS_MDK_DIALOG(obj)         (GTK_CHECK_TYPE((obj), GTK_TYPE_MDK_DIALOG))
#define GTK_IS_MDK_DIALOG_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GTK_TYPE_MDK_DIALOG))

typedef struct _GtkMdkDialog       GtkMdkDialog;
typedef struct _GtkMdkDialogClass  GtkMdkDialogClass;

typedef enum
{
  GTK_DIALOG_OK,
  GTK_DIALOG_OK_CANCEL,
  GTK_DIALOG_YES_NO
} GtkMdkDialogType;

typedef enum
{
  STOP_ICON,
  ASK_ICON,
  BANG_ICON,
  NONE_ICON  
} GtkMdkDialogIcon;

struct _GtkMdkDialog
{
  GtkDialog dialog;

  GtkMdkDialogType type;
  GtkMdkDialogIcon icon;
  GtkWidget *Buttons[4];

  gint NbButtons;
  gboolean close_on_click;
  gboolean just_hide;
  gboolean modal;
  GtkAccelGroup *accelerators;
  gchar *title;
  gchar *text;
  GtkWidget *hbox;
  GtkWidget *Pixmap;
  GtkWidget *Label;
};

struct _GtkMdkDialogClass
{
  GtkDialogClass parent_class;
  void (* clicked)(GtkMdkDialog *dialog, gint button_number);
  gboolean (* close)(GtkMdkDialog * dialog);
};

/* MdkDialog */

GtkType    gtk_mdk_dialog_get_type(void);
GtkWidget *gtk_mdk_dialog_new(GtkMdkDialogType type,
                              GtkMdkDialogIcon icon,
                              gchar *title,
                              gchar *text);

void gtk_mdk_dialog_set_parent(GtkMdkDialog *dialog,
                               GtkWindow *parent);

/* Connect to the "clicked" signal of a single button */
void gtk_mdk_dialog_button_connect(GtkMdkDialog *dialog,
                                   gint button,
                                   GtkSignalFunc callback,
                                   gpointer data);

/* Connect the object to the "clicked" signal of a single button */
void gtk_mdk_dialog_button_connect_object(GtkMdkDialog *dialog,
                                          gint button,
                                          GtkSignalFunc callback,
                                          GtkObject *obj);

/* Run the dialog, return the button # that was pressed or -1 if none.
 *    (this sets the dialog modal while it blocks)
 */
gint gtk_mdk_dialog_run(GtkMdkDialog *dialog);
gint gtk_mdk_dialog_run_and_close(GtkMdkDialog *dialog);

/* Set the default button. - it will have a little highlight,
 *    and pressing return will activate it. */
void gtk_mdk_dialog_set_default(GtkMdkDialog *dialog,
                                gint button);

/* Set the accelerator for a button. Note that there are two
 * default accelerators: "Return" will be the same as clicking
 * the default button, and "Escape" will emit delete_event.
 * (Note: neither of these is in the accelerator table,
 * Return is a Gtk default and Escape comes from a key press event handler.)
 */
void gtk_mdk_dialog_set_accelerator(GtkMdkDialog * dialog,
                                    gint button,
                                    const guchar accelerator_key,
                                    guint8 accelerator_mods);

/* Hide and optionally destroy. Destroys by default, use close_hides()
 * to change this.
 */
void gtk_mdk_dialog_close(GtkMdkDialog *dialog);

/* Make _close just hide, not destroy. */
void gtk_mdk_dialog_close_hides(GtkMdkDialog *dialog,
                                gboolean just_hide);
 
/* By default, a click on any button close the dialog.
 * Use this function to change this behaviour
 */
void gtk_mdk_dialog_close_on_click(GtkMdkDialog * dialog,
                                   gboolean close_on_click);


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GTK_MDK_DIALOG_H__ */

