/* gtkwizard.h
 *
 * This file is part of the MandrakeSoft Gtk Widgets Package
 * Copyright (C) 2000 DindinX <odin@mandrakesoft.com>
 * Copyright (C) 2000 MandrakeSoft
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_WIZARD_H__
#define __GTK_WIZARD_H__

#include <gtk/gtkvbox.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_WIZARD            (gtk_wizard_get_type())
#define GTK_WIZARD(obj)            (GTK_CHECK_CAST((obj), GTK_TYPE_WIZARD, GtkWizard))
#define GTK_WIZARD_CLASS(klass)    (GTK_CHECK_CLASS_CAST((klass), GTK_TYPE_WIZARD, GtkWizardClass))
#define GTK_IS_WIZARD(obj)         (GTK_CHECK_TYPE((obj), GTK_TYPE_WIZARD))
#define GTK_IS_WIZARD_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GTK_TYPE_WIZARD))

typedef struct _GtkWizard       GtkWizard;
typedef struct _GtkWizardClass  GtkWizardClass;

struct _GtkWizard
{
  GtkVBox vbox;

  GtkWidget *title;
  GtkWidget *left_pixmap;
  GtkWidget *notebook;
  GtkWidget *help_button;
  GtkWidget *back_button;
  GtkWidget *next_button;
  GtkWidget *cancel_button;
  GdkColor   midnight_blue;
  GdkColor   left_blue;

  /* Private */
  guint nb_pages;
  gchar *title_string;
  GdkFont *title_font;
  gchar *subtitle_string;
  GdkFont *subtitle_font;
  GdkPixmap *top_pixmap;
};

struct _GtkWizardClass
{
  GtkVBoxClass parent_class;
  void (*page_enter)(GtkWizard *wizard, guint page);
  void (*page_exit)(GtkWizard *wizard, guint page);
};

/* Wizard */

GtkType    gtk_wizard_get_type(void);
GtkWidget *gtk_wizard_new(void);
void gtk_wizard_add_page(GtkWizard *wizard, GtkWidget *Page);
void gtk_wizard_add_page_with_title(GtkWizard *wizard, GtkWidget *Page);
void gtk_wizard_page_set_page_title(GtkWizard *wizard, guint page,
                                    gchar *page_title);
void gtk_wizard_set_title(GtkWizard *wizard, gchar *str);
void gtk_wizard_set_subtitle(GtkWizard *wizard, gchar *str);
void gtk_wizard_set_top_pixmap_from_file(GtkWizard *wizard, gchar *filename);
void gtk_wizard_set_top_pixmap(GtkWizard *wizard, gchar **data);
void gtk_wizard_prev_page(GtkWizard *wizard);
void gtk_wizard_next_page(GtkWizard *wizard);
  
  

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GTK_WIZARD_H__ */
